@@ -11,7 +11,7 @@ use File::HomeDir::Unix ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.83_01';
+	$VERSION = '0.85_01';
 	@ISA     = 'File::HomeDir::Unix';
 }
 
@@ -31,7 +31,15 @@ SCOPE: {
 
 sub my_home {
 	my ($class) = @_;
-	require Mac::Files;
+
+	# A lot of unix people and unix-derived tools rely on
+	# the ability to overload HOME. We will support it too
+	# so that they can replace raw HOME calls with File::HomeDir.
+	if ( exists $ENV{HOME} and defined $ENV{HOME} ) {
+		return $ENV{HOME};
+	}
+	
+  require Mac::Files;
 	$class->_find_folder(
 		Mac::Files::kCurrentUserFolderType(),
 		);
@@ -160,6 +168,10 @@ This module provides Darwin-specific implementations for determining
 common user directories.  In normal usage this module will always be
 used via L<File::HomeDir>.
 
+Note -- since this module requires Mac::Carbon and Mac::Carbon does not
+work with 64-bit perls, on such systems, File::HomeDir will fall back
+to File::HomeDir::Unix instead.
+
 =head1 SYNOPSIS
 
   use File::HomeDir;
